about summary refs log tree commit diff stats
path: root/082persist.cc
diff options
context:
space:
mode:
Diffstat (limited to '082persist.cc')
-rw-r--r--082persist.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/082persist.cc b/082persist.cc
index 2c798cfb..63516bb2 100644
--- a/082persist.cc
+++ b/082persist.cc
@@ -1,13 +1,13 @@
 //: Dead simple persistence.
 //:   'read' - reads string from a hardcoded file
 //:   'save' - writes string to a hardcoded file
 
 :(before "End Primitive Recipe Declarations")
-READ,
+RESTORE,
 :(before "End Primitive Recipe Numbers")
-Recipe_ordinal["read"] = READ;
+Recipe_ordinal["restore"] = RESTORE;
 :(before "End Primitive Recipe Implementations")
-case READ: {
+case RESTORE: {
   products.resize(1);
   products.at(0).push_back(new_string(slurp("lesson/recipe.mu")));
   break;
@@ -1,13 +1,13 @@
 //: Dead simple persistence.
-//:   'read' - reads string from a hardcoded file
+//:   'restore' - reads string from a hardcoded file
 //:   'save' - writes string to a hardcoded file
 